@@ -6,25 +6,25 @@
 
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustSec/logos/main/rustsec-logo-lg.png",
-    html_root_url = "https://docs.rs/rustsec/0.24.3"
+    html_root_url = "https://docs.rs/rustsec/0.25.1"
 )]
 #![forbid(unsafe_code)]
 #![warn(missing_docs, rust_2018_idioms, unused_qualifications)]
 
 #[macro_use]
-pub mod error;
+mod error;
 
 pub mod advisory;
-pub mod collection;
+mod collection;
 pub mod database;
 pub mod osv;
 pub mod report;
 pub mod repository;
-pub mod vulnerability;
+mod vulnerability;
 pub mod warning;
 
 #[cfg(feature = "fix")]
-pub mod fixer;
+mod fixer;
 
 #[cfg(feature = "git")]
 pub mod registry;
@@ -38,12 +38,15 @@ pub use crate::{
     advisory::Advisory,
     collection::Collection,
     database::Database,
-    error::{Error, ErrorKind},
+    error::{Error, ErrorKind, Result},
     report::Report,
     vulnerability::Vulnerability,
     warning::Warning,
 };
 
+#[cfg(feature = "fix")]
+pub use crate::fixer::Fixer;
+
 #[cfg(feature = "git")]
 pub use crate::repository::git::Repository;
 
